* SPSS 16.0 for Windows, Release 16.0.1 .
* Diese Datei: E:\bsn\Workshop_06_2008\SPSS-Beispiele\beispiel6.sps (02.03.2009) .
set length none.
set width 132.
set header no.
set mxwarns=5.  

* CD '<Arbeitsverzeichnis>'.

* ========================================================================.
* Beispiel 6: Gesamtwerte mit gebundener Hochrechnung                     .
*             (Regressionsschtzung) .
* ========================================================================.

* Quelle: 
  Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
  Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
  File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
       http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
       sp-fehler/SPSS_Beispiele.zip .

get file = "mz02cf_Beisp.sav"
            /keep ef1 ef3 ef30 ef32 ef52 ef127 ef504 ef505 ef712 ef750g.
DATASET NAME DataSet1 WINDOW=FRONT.

missing values all().
compute id = $casenum.

* Variablenabgenzungen analog zu Beispiel 1.
compute schicht = ef1*10 + ef712.
compute f = 0.01 * 0.035.
compute d = 1/f.   /* Designgewicht (Bsp1 "w") */
compute sub = (ef505<=2 & ef30>=15).
compute y = (ef504=2) * sub.
formats y sub (f1.0).


* Vorbereitung Poststratifikation.
* 1a) Anpassung: Geschl. * Staatsangeh., Sold., Wehrpfl.
* compute anp=0.
do if (ef52=1 & ef32=1 & ef127<>9 & ef127<>10). 
compute anp=1.
else if (ef52=1 & ef32=2) .
compute anp=2.
else if (ef52<>1 & ef32=1).
compute anp=3.
else if (ef52<>1 & ef32=2).
compute anp=4.
else if (ef52=1 & ef32=1 & ef127=9).
compute anp=5.
else if (ef52=1 & ef32=1 & ef127=10).
compute anp=6.
end if.
variable label anp 'Anpassungsklasse'.
value label anp
  1 'Deutsche Maenner'                  2 'Deutsche Frauen'
  3 'Auslaendische Maenner'             4 'Auslaendische Frauen'
  5 'Zeit-/Berufssold., BGS, Ber.pol.'  6 'Grundwehrdienstleistende'.
formats anp (f1).
* 1b) Proxy Anpassungsschicht .
compute anpschicht=sub*(ef1*10+anp).
formats anpschicht (f4).


* 2) Berechnen des Regressionskoeffizienten mit Regression y  "Erwerbslos".
*    auf X "Hilfsmerkmale" bzw. "Anpassungsschicht"                       .  
*    Da Anpassungsschichten disjunkt: B-Dach_g = y-quer_s_g = y_Dach      .
*    einfacher berechenbar mit    aggregate ... B_dach = mean(y)  (s.u.)  .
* [A] Gewichtung analog Beispiel 5 (w_anp) .
* 3) Berechnung des gewichteten Gesamtwertes ber die Anpassungsschichten .
*       ef750g rechnet auf 100 in Population hoch .
compute wy = ef750g*100 * (ef505<=2).
*           Populationswerte designgewichtet.
compute dy = d * (ef505<=2).
aggregate outfile = * mode=addvariables
       /break anpschicht
       /B_dach = mean(y)
       /M_k = sum(wy)
       /M_Dach_k = sum(dy).

compute g1 = M_k/M_Dach_k*sub.
recode g1 (sysmis=0).
compute w1 = d*g1.
recode w1 (sysmis=0).

sort cases by id.

*  4) Varianzschtzung mit Hilfsvariable u .
compute u1=g1 * (y-B_dach).
* Schtzung des Gesamtwertes ---> S.E. irrelevant <---.
CSPLAN ANALYSIS
  /PLAN FILE='beispiel6_At.csaplan'
  /PLANVARS ANALYSISWEIGHT=w1
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel6_At.csaplan'
 /SUMMARY VARIABLES =y
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS COUNT .
* Schtzung des Standardfehlers  --> Total irrelevant <---. 
CSPLAN ANALYSIS
  /PLAN FILE='beispiel6_Ase.csaplan'
  /PLANVARS ANALYSISWEIGHT=d
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel6_Ase.csaplan'
 /SUMMARY VARIABLES =u1
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS SE .





* [B] Gewichtung analog Beispiel 5 (w_y) .
*      g2: Korrekturfaktoren der y-Werte pro Anpassungsschicht .
compute wy = ef750g * 0.035 * y.
aggregate outfile = * mode=addvariables
       /break anpschicht
       /wy_k = sum(wy)
       /ny_k = sum(y).
sort cases by id.
* Korrekturfaktor der y-Werte .
compute g2 = wy_k/ny_k.
recode g2 (sysmis=0).
*  Endgewicht = Korrekturfaktor * Designgewicht .
compute w2 = d * g2.
compute u2 = g2*(y-B_Dach).
* Schtzung des Gesamtwertes ---> S.E. irrelevant <---.
CSPLAN ANALYSIS
  /PLAN FILE='beispiel6_Bt.csaplan'
  /PLANVARS ANALYSISWEIGHT=w2
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel6_Bt.csaplan'
 /SUMMARY VARIABLES =y
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS COUNT .
* Schtzung des Standardfehlers --> Total irrelevant <---. 
CSPLAN ANALYSIS
  /PLAN FILE='beispiel6_Bse.csaplan'
  /PLANVARS ANALYSISWEIGHT=d
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'E:\bsn\Workshop_06_2008\SPSS-Beispiele\beispiel6_Bse.csaplan'
 /SUMMARY VARIABLES =u2
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS SE .


* [C] Gewichtung mit ef750 direkt (ohne Normierung auf 1%-MZ) analog zu .
*     frheren Programmen (Rendtel/Schimpl-Neimanns 2001); z.B. varmz_a.do .
compute g3 = ef750g*0.035*sub .
compute w3 = d * g3.
compute u3 = g3*(y-B_Dach) .
* Schtzung des Gesamtwertes ---> S.E. irrelevant <---.
CSPLAN ANALYSIS
  /PLAN FILE='beispiel6_Ct.csaplan'
  /PLANVARS ANALYSISWEIGHT=w3
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel6_Ct.csaplan'
 /SUMMARY VARIABLES =y
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS COUNT .
* Schtzung des Standardfehlers --> Total irrelevant <---. 
CSPLAN ANALYSIS
  /PLAN FILE='beispiel6_Cse.csaplan'
  /PLANVARS ANALYSISWEIGHT=d
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel6_Cse.csaplan'
 /SUMMARY VARIABLES =u3
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS SE .

